Subject: [PATCH v2 02/30] gnu: gnupg: Autoload unless used by Guix.

From: Maxime Devos <[email-masked]>
Date: Sat, 3 Sep 2022 18:43:04 +0200

See first commit in the series for the procedure.
---
 gnu/packages/gnupg.scm | 74 ++++++++++++++++++++++--------------------
 1 file changed, 39 insertions(+), 35 deletions(-)

diff --git a/gnu/packages/gnupg.scm b/gnu/packages/gnupg.scm
index 90215a6877..13a8194fb9 100644
--- a/gnu/packages/gnupg.scm
+++ b/gnu/packages/gnupg.scm
@@ -41,41 +41,45 @@
 (define-module (gnu packages gnupg)
   #:use-module ((guix licenses) #:prefix license:)
   #:use-module (gnu packages)
-  #:use-module (gnu packages adns)
-  #:use-module (gnu packages autotools)
-  #:use-module (gnu packages base)
-  #:use-module (gnu packages curl)
-  #:use-module (gnu packages crypto)
-  #:use-module (gnu packages emacs)
-  #:use-module (gnu packages enlightenment)
-  #:use-module (gnu packages gettext)
-  #:use-module (gnu packages guile)
-  #:use-module (gnu packages openldap)
-  #:use-module (gnu packages perl)
-  #:use-module (gnu packages perl-check)
-  #:use-module (gnu packages pth)
-  #:use-module (gnu packages python)
-  #:use-module (gnu packages python-xyz)
-  #:use-module (gnu packages qt)
-  #:use-module (gnu packages readline)
-  #:use-module (gnu packages compression)
-  #:use-module (gnu packages gtk)
-  #:use-module (gnu packages glib)
-  #:use-module (gnu packages gnome)
-  #:use-module (gnu packages pkg-config)
-  #:use-module (gnu packages ncurses)
-  #:use-module (gnu packages security-token)
-  #:use-module (gnu packages sqlite)
-  #:use-module (gnu packages swig)
-  #:use-module (gnu packages texinfo)
-  #:use-module (gnu packages tls)
-  #:use-module (gnu packages tor)
-  #:use-module (gnu packages web)
-  #:use-module (gnu packages xorg)
-  #:use-module (gnu packages xdisorg)
-  #:use-module (gnu packages xml)
-  #:use-module (gnu packages popt)
-  #:use-module (gnu packages xdisorg)
+  #:use-module (gnu packages autotools) ; required by 'guix build -d guix"
+  #:autoload (gnu packages base) (which)
+  #:autoload (gnu packages curl) (curl)
+  #:autoload (gnu packages crypto) (libmd)
+  #:autoload (gnu packages enlightenment) (efl)
+  #:use-module (gnu packages gettext) ; required by "guix build -d guix"
+  #:use-module (gnu packages guile) ; required by "guix build -d guix"
+  #:autoload (gnu packages openldap) (openldap)
+  #:autoload (gnu packages perl)
+  (perl perl-clone perl-config-general perl-file-homedir perl-file-sharedir
+        perl-file-which perl-ipc-system-simple perl-json
+        perl-list-moreutils perl-module-build perl-module-install
+        perl-mime-tools perl-moo perl-moox-handlesvia perl-moox-late
+        perl-moox-options perl-moox-strictconstructor perl-namespace-clean
+        perl-net-idn-encode
+        perl-path-tiny perl-strictures-2 perl-text-template perl-time-duration
+        perl-time-duration-parse perl-try-tiny perl-type-tiny
+        perl-types-path-tiny)
+  #:autoload (gnu packages perl-check)
+  (perl-test-most perl-test-trap)
+  #:autoload (gnu packages pth) (pth)
+  #:autoload (gnu packages qt) (qtbase-5)
+  #:autoload (gnu packages readline) (readline)
+  #:autoload (gnu packages compression) (zlib bzip2)
+  #:autoload (gnu packages gtk) (gtk+-2 perl-pango)
+  #:autoload (gnu packages glib) (glib perl-net-dbus)
+  #:autoload (gnu packages gnome) (libsecret gcr)
+  #:use-module (gnu packages pkg-config) ; required by "guix build -d guix"
+  #:autoload (gnu packages ncurses) (ncurses)
+  #:autoload (gnu packages security-token) (pcsc-lite)
+  #:autoload (gnu packages sqlite) (sqlite)
+  #:autoload (gnu packages swig) (swig)
+  #:use-module (gnu packages texinfo) ; required by "guix build -d guix"
+  #:autoload (gnu packages tls) (gnutls)
+  #:autoload (gnu packages tor) (torsocks)
+  #:autoload (gnu packages web) (perl-lwp-online)
+  #:autoload (gnu packages xorg) (xorg-server-for-tests)
+  #:autoload (gnu packages xdisorg) (rofi bemenu)
+  #:autoload (gnu packages popt) (popt)
   #:use-module (guix gexp)
   #:use-module (guix packages)
   #:use-module (guix download)
-- 
2.37.2